//
//  PlayGround
//
//  Copyright 2015 Daniel Cohen Gindi & Philipp Jahoda
//  Copyright © 2017 thierry Hentic.
//  A port of MPAndroidChart for iOS
//  Licensed under Apache License 2.0
//
//  https://github.com/danielgindi/ios-charts
/*:
 ****
 [Menu](Menu)
 
 [Previous](@previous)
 ****
 */

//: # Bubble Chart
import Cocoa
import Charts
import PlaygroundSupport



func randomColor()->NSUIColor
{
    let redColor    = CGFloat( Double(arc4random_uniform(255)) / 255.0 )
    let greenColor  = CGFloat( Double(arc4random_uniform(255)) / 255.0 )
    let blueColor   = CGFloat( Double(arc4random_uniform(255)) / 255.0 )
    let color = NSUIColor(red: redColor, green: greenColor, blue: blueColor, alpha: 1.0)
    return color
}


let r = CGRect(x: 0, y: 0, width: 600, height: 600)
var chartView = BubbleChartView(frame: r)
//: ### General
chartView.drawGridBackgroundEnabled = true
/*:---*/
//: ### xAxis
let xAxis                           = chartView.xAxis
xAxis.labelPosition                 = .bottom
xAxis.axisMinimum                   = 0.0
xAxis.axisMaximum                   = 120.0
xAxis.granularity                   = 1.0

xAxis.nameAxis = "Impact"
xAxis.nameAxisEnabled = true
/*:---*/
//: ### LeftAxis
let leftAxis                        = chartView.leftAxis
leftAxis.drawGridLinesEnabled       = true
leftAxis.axisMinimum                = 0.0

leftAxis.nameAxis = "Probability"
leftAxis.nameAxisEnabled = true
/*:---*/
//: ### RightAxis
let rightAxis                       = chartView.rightAxis
rightAxis.drawGridLinesEnabled      = true
rightAxis.axisMinimum               = 0.0

/*:---*/
//: ### Legend
let legend                          = chartView.legend
legend.wordWrapEnabled              = true
legend.horizontalAlignment          = .left
legend.verticalAlignment            = .bottom
legend.orientation                  = .vertical
legend.drawInside                   = false
/*:---*/
//: ### Description
chartView.chartDescription?.enabled = false
/*:---*/
//: ### BubbleChartDataEntry

var entries = [BubbleChartDataEntry]()
let data = BubbleChartData()

for index in 0..<10
{
    entries.removeAll()

    let x = Double(arc4random_uniform(100))
    let y = Double(arc4random_uniform(100)) + 50.0
    let size = Double(arc4random_uniform(30) )
    entries.append(BubbleChartDataEntry(x: x, y: y, size: CGFloat( size )))
/*:---*/
//: ### BubbleChartDataSet
    let set = BubbleChartDataSet(values: entries, label: "DataSet" + String(index))
    let color = randomColor()
    set.setColor( color )
    set.valueTextColor = NSUIColor.black
    set.valueFont = NSUIFont.systemFont(ofSize: CGFloat(10.0))
   set.drawValuesEnabled = true
   set.normalizeSizeEnabled = false
    /*:---*/
//: ### BubbleChartData

    data.addDataSet(set)
}
chartView.data = data
chartView.animate(xAxisDuration: 1.0, yAxisDuration: 1.0)
/*:---*/
//: ### Setup for the live view
PlaygroundPage.current.liveView = chartView
/*:
 ****
 [Menu](Menu)
 
 [Previous](@previous)
 ****
 */

