//
//  PlayGround
//
//  Copyright 2015 Daniel Cohen Gindi & Philipp Jahoda
//  Copyright © 2017 thierry Hentic.
//  A port of MPAndroidChart for iOS
//  Licensed under Apache License 2.0
//
//  https://github.com/danielgindi/ios-charts
/*:
 ****
 [Menu](Menu)
 
 [Previous](@previous) | [Next](@next)
 ****
 */

//: # Candle Chart
import Cocoa
import Charts
import PlaygroundSupport


func randomFloatBetween(from: Float, to: Float)->Float
{
    return Float(arc4random_uniform( UInt32(to - from ))) + Float(from)
}


let ITEM_COUNT  = 20


let r = CGRect(x: 0, y: 0, width: 600, height: 600)
var chartView = CandleStickChartView(frame: r)
//: ### General

chartView.drawGridBackgroundEnabled = true
chartView.drawBordersEnabled = true

//: ### xAxis
let xAxis                           = chartView.xAxis
xAxis.labelPosition                 = .bottom
xAxis.axisMinimum                   = 0.0
xAxis.granularity                   = 1.0

xAxis.nameAxis = "Event"
xAxis.nameAxisEnabled = true

//: ### LeftAxis
let leftAxis                        = chartView.leftAxis
leftAxis.drawGridLinesEnabled       = true
leftAxis.axisMinimum                = 0.0

leftAxis.nameAxis = "Speed (km/h)"
leftAxis.nameAxisEnabled = true

//: ### RightAxis
let rightAxis                       = chartView.rightAxis
rightAxis.drawGridLinesEnabled      = true
rightAxis.axisMinimum               = 0.0

//: ### Legend
let legend                          = chartView.legend
legend.wordWrapEnabled              = true
legend.horizontalAlignment          = .center
legend.verticalAlignment            = .bottom
legend.orientation                  = .horizontal
legend.drawInside                   = false

//: ### Description
chartView.chartDescription?.enabled = false

//: ### CandleChartDataEntry
var entries = [CandleChartDataEntry]()

for i in 0..<ITEM_COUNT
{
    let mult: Float = 50.0
    let val = randomFloatBetween(from: mult, to: mult + 40)
    let high = randomFloatBetween(from: 8, to: 17)
    let low = randomFloatBetween(from: 8, to: 17)
    let open = randomFloatBetween(from: 1, to: 7)
    let close = randomFloatBetween(from: 1, to: 7)
    let even = i % 2 == 0
    
    entries.append(CandleChartDataEntry(x: Double(i),
                                shadowH: Double(val + high),
                                shadowL: Double(val - low),
                                open: Double(even ? val + open : val - open),
                                close: Double(even ? val - close : val + close)))
    }
/*:---*/
//: ### CandleChartDataSet
let set = CandleChartDataSet(values: entries, label: "Candle DataSet")
set.colors = [#colorLiteral(red: 0.2745098174, green: 0.4862745106, blue: 0.1411764771, alpha: 1), #colorLiteral(red: 0.5568627715, green: 0.3529411852, blue: 0.9686274529, alpha: 1)]

set.decreasingColor = #colorLiteral(red: 1, green: 0.1491314173, blue: 0, alpha: 1)
set.shadowColor = NSColor.red
set.valueFont = NSUIFont.systemFont(ofSize: CGFloat(10.0))
set.drawValuesEnabled = true
set.shadowWidth = 1.5
set.showCandleBar = true
/*:---*/
//: ### CandleChartData
let data = CandleChartData()
data.addDataSet(set)
chartView.data = data
chartView.animate(xAxisDuration: 1.0, yAxisDuration: 1.0)
/*:---*/
//: ### Setup for the live view
PlaygroundPage.current.liveView = chartView

/*:
 ****
 [Previous](@previous) | [Next](@next)
 */


