//: [Previous](@previous)

//
//  PlayGround
//
//  Copyright 2015 Daniel Cohen Gindi & Philipp Jahoda
//  Copyright © 2017 thierry Hentic.
//  A port of MPAndroidChart for iOS
//  Licensed under Apache License 2.0
//
//  https://github.com/danielgindi/ios-charts
/*:
 ****
 [Menu](Menu)
 
 [Previous](@previous) | [Next](@next)
 ****
 */

//: # Half Pie Chart
import Cocoa
import Charts
import PlaygroundSupport


let r = CGRect(x: 0, y: 0, width: 600, height: 600)
var chartView = PieChartView(frame: r)
/*:---*/
//: ### General
chartView.backgroundColor = #colorLiteral(red: 1, green: 1, blue: 1, alpha: 1)

chartView.holeColor                      =  #colorLiteral(red: 0.9999960065, green: 1, blue: 1, alpha: 1)
chartView.transparentCircleColor         = NSUIColor.white.withAlphaComponent(0.43)
chartView.highlightPerTapEnabled         = true
chartView.maxAngle                       = 180.0
chartView.drawHoleEnabled                = true
chartView.rotationAngle                  = 0.0
chartView.rotationEnabled                = true

chartView.usePercentValuesEnabled        = true
chartView.drawSlicesUnderHoleEnabled     = false
chartView.holeRadiusPercent              = 0.58
chartView.transparentCircleRadiusPercent = 0.61
chartView.drawCenterTextEnabled          = true
/*:---*/
//: ### Description
chartView.chartDescription?.enabled = false
/*:---*/
//: ###  Legend
let legend = chartView.legend
legend.horizontalAlignment = .center
legend.verticalAlignment = .top
legend.orientation = .horizontal
legend.drawInside = false
legend.xEntrySpace = 7.0
legend.yEntrySpace = 0.0
legend.yOffset = 0.0


let paragraphStyle: NSMutableParagraphStyle = NSParagraphStyle.default().mutableCopy() as! NSMutableParagraphStyle
paragraphStyle.lineBreakMode = .byTruncatingTail
paragraphStyle.alignment = .center

let centerText: NSMutableAttributedString = NSMutableAttributedString(string: "Charts\nby Daniel Cohen Gindi")
centerText.setAttributes([NSFontAttributeName: NSFont(name: "HelveticaNeue-Light", size: 15.0)!, NSParagraphStyleAttributeName: paragraphStyle], range: NSMakeRange(0, centerText.length))

centerText.addAttributes([NSFontAttributeName: NSFont(name: "HelveticaNeue-Light", size: 13.0)!, NSForegroundColorAttributeName: NSColor.gray], range: NSMakeRange(10, centerText.length - 10))

centerText.addAttributes([NSFontAttributeName: NSFont(name: "HelveticaNeue-LightItalic", size: 13.0)!, NSForegroundColorAttributeName: NSColor(red: 51 / 255.0, green: 181 / 255.0, blue: 229 / 255.0, alpha: 1.0)], range: NSMakeRange(centerText.length - 19, 19))

chartView.centerAttributedText = centerText

// entry label styling
chartView.entryLabelColor =  #colorLiteral(red: 0.9999960065, green: 1, blue: 1, alpha: 1)
chartView.entryLabelFont = NSUIFont(name: "HelveticaNeue-Light", size: CGFloat(12.0))

// Half chart
chartView.rotationAngle = 180.0
// Rotate to make the half on the upper side
chartView.centerTextOffset = CGPoint(x: CGFloat(0.0), y: CGFloat(-20.0))
/*:---*/
//: ###  PieChartDataEntry
let count = 6
let range = 100.0
let mult = range
let parties = ["Party A", "Party B", "Party C", "Party D", "Party E", "Party F", "Party G", "Party H", "Party I", "Party J", "Party K", "Party L", "Party M", "Party N", "Party O", "Party P", "Party Q", "Party R", "Party S", "Party T", "Party U", "Party V", "Party W", "Party X", "Party Y", "Party Z"]

var values = [PieChartDataEntry]()

// IMPORTANT: In a PieChart, no values (Entry) should have the same xIndex (even if from different DataSets), since no values can be drawn above each other.

for i in 0..<count
{
    values.append(PieChartDataEntry(value: (Double(arc4random_uniform(UInt32(mult))) + mult / 5), label: parties[i % parties.count]))
}
/*:---*/
//: ###  PieChartDataSet
let dataSet = PieChartDataSet(values: values, label: "Election Results")
dataSet.sliceSpace = 3.0
dataSet.selectionShift = 5.0
dataSet.colors = ChartColorTemplates.material()
/*:---*/
//: ###  PieChartData
let data = PieChartData()
data.addDataSet(dataSet)

let pFormatter = NumberFormatter()
pFormatter.numberStyle = .percent
pFormatter.maximumFractionDigits = 1
pFormatter.multiplier = 1.0
pFormatter.percentSymbol = " %"
data.setValueFormatter(DefaultValueFormatter(formatter : pFormatter  ))

data.setValueFont( NSUIFont(name: "HelveticaNeue-Light", size: CGFloat(11.0)))
data.setValueTextColor( NSUIColor.white)
chartView.data = data
chartView.needsDisplay = true

chartView.animate(xAxisDuration: 2.0, yAxisDuration: 2.0, easingOption: .easeInBounce)
/*:---*/
//: ### Setup for the live view
PlaygroundPage.current.liveView = chartView
/*:
 ****
 [Previous](@previous) | [Next](@next)
 */
