//
//  PlayGround
//
//  Copyright 2015 Daniel Cohen Gindi & Philipp Jahoda
//  Copyright © 2017 thierry Hentic.
//  A port of MPAndroidChart for iOS
//  Licensed under Apache License 2.0
//
//  https://github.com/danielgindi/ios-charts
/*:
 ****
 [Menu](Menu)
 
 [Previous](@previous) | [Next](@next)
 ****
 */

//: # Line Chart
import Cocoa
import Charts
import PlaygroundSupport



let r = CGRect(x: 0, y: 0, width: 600, height: 600)
var chartView = LineChartView(frame: r)
/*:---*/
//: ### General
chartView.dragEnabled = true
chartView.setScaleEnabled ( true)
chartView.drawGridBackgroundEnabled = false
chartView.pinchZoomEnabled = true
chartView.backgroundColor = #colorLiteral(red: 0.8039215803, green: 0.8039215803, blue: 0.8039215803, alpha: 1)
chartView.borderColor = NSUIColor.black
chartView.borderLineWidth = 1.0
chartView.drawBordersEnabled = true
/*:---*/
//: ### xAxis
let xAxis = chartView.xAxis
xAxis.labelFont = NSUIFont.systemFont(ofSize: CGFloat(12.0))
xAxis.labelTextColor = #colorLiteral(red: 0.1764705926, green: 0.01176470611, blue: 0.5607843399, alpha: 1)
xAxis.drawGridLinesEnabled = true
xAxis.drawAxisLineEnabled = true
xAxis.labelPosition = .bottom
xAxis.labelRotationAngle = 0


xAxis.nameAxis = "Date (s)"
xAxis.nameAxisEnabled = true

//: ### LeftAxis
let leftAxis = chartView.leftAxis
leftAxis.labelTextColor = #colorLiteral(red: 0.01680417731, green: 0.1983509958, blue: 1, alpha: 1)
//leftAxis.axisMaximum = 200.0
//leftAxis.axisMinimum = 0.0
leftAxis.drawGridLinesEnabled = true
leftAxis.drawZeroLineEnabled = false
leftAxis.granularityEnabled = true

leftAxis.nameAxis = "Speed (km/h)"
leftAxis.nameAxisEnabled = false
/*:---*/
//: ### RightAxis
let rightAxis = chartView.rightAxis
rightAxis.labelTextColor = #colorLiteral(red: 1, green: 0.1474981606, blue: 0, alpha: 1)
rightAxis.drawGridLinesEnabled = false
rightAxis.granularityEnabled = false

rightAxis.nameAxis = "Pressure (mBar)"
rightAxis.nameAxisEnabled = false
/*:---*/
//: ### Legend
let legend = chartView.legend
legend.font = NSUIFont(name: "HelveticaNeue-Light", size: CGFloat(12.0))!
legend.textColor = NSUIColor.black
legend.form = .square
legend.drawInside = false
legend.orientation = .horizontal
legend.verticalAlignment = .bottom
legend.horizontalAlignment = .left
/*:---*/
//: ### Description
chartView.chartDescription?.enabled = false
/*:---*/
//: ### ChartDataEntry
var yVals1 = [ChartDataEntry]()
var yVals2 = [ChartDataEntry]()
var yVals3 = [ChartDataEntry]()

let range = 30.0

for i in 0..<20 {
    let mult: Double = range / 2.0
    let val = Double(arc4random_uniform(UInt32(mult))) + 50
    yVals1.append(ChartDataEntry(x: Double(i), y: val))
}

for i in 0..<20 - 1 {
    let mult: Double = range
    let val = Double(arc4random_uniform(UInt32(mult))) + 450
    yVals2.append(ChartDataEntry(x: Double(i), y: val))
}

for i in 0..<20 {
    let mult: Double = range
    let val = Double(arc4random_uniform(UInt32(mult))) + 500
    yVals3.append(ChartDataEntry(x: Double(i), y: val))
}

/*let populationData : [[Int]] = [[ 10, 29], [11, 28], [12, 28], [13, 28], [14, 27], [15, 27], [16, 27], [17, 27], [18, 27], [19, 27], [20, 28], [21, 30], [22, 31 ]]

var entries = [ChartDataEntry]()
for i in 0..<populationData.count
{
    entries.append(ChartDataEntry(x: Double(populationData[i][0]), y: Double(populationData[i][1])))
}

let data = LineChartData()
//----------------------------- dataset intensified ---------------------------------------
let dataset = LineChartDataSet(values: entries, label: nil)
dataset.axisDependency = .left
dataset.colors = [.yellow]
dataset.mode = .cubicBezier
dataset.cubicIntensity = 0.1

// kicked out circlre from line
dataset.drawCirclesEnabled = false

dataset.lineWidth = 2.0
dataset.fillAlpha = 100
dataset.drawFilledEnabled = true
dataset.fillColor = NSUIColor.orange
dataset.highlightColor = NSUIColor.brown

dataset.drawValuesEnabled = false

data.addDataSet(dataset)*/
/*:---*/
//: ### LineChartDataSet
var set1 = LineChartDataSet()
var set2 = LineChartDataSet()
var set3 = LineChartDataSet()

set1 = LineChartDataSet(values: yVals1, label: "DataSet 1")
set1.axisDependency = .left
set1.mode = .stepped
set1.colors = [#colorLiteral(red: 0.215686274509804, green: 0.709803921568627, blue: 0.898039215686275, alpha: 1.0)]
set1.circleColors = [NSUIColor.white]
set1.lineWidth = 2.0
set1.circleRadius = 3.0
set1.fillAlpha = 65 / 255.0
set1.fillColor = #colorLiteral(red: 0.215686274509804, green: 0.709803921568627, blue: 0.898039215686275, alpha: 1.0)
set1.highlightColor = NSUIColor.blue
set1.highlightEnabled = true
set1.drawCirclesEnabled = false

let gradientColors =
    [(ChartColorTemplates.colorFromString( "#00ff0000").cgColor ),
     (ChartColorTemplates.colorFromString( "#ffff0000").cgColor )]

let gradient: CGGradient? = CGGradient(colorsSpace: nil, colors: (gradientColors as CFArray?)!, locations: nil)
set1.fillAlpha = 1.0
set1.fill = Fill(linearGradient: gradient!, angle: 90.0)
set1.drawFilledEnabled = true


set2 = LineChartDataSet(values: yVals2, label: "DataSet 2")
set2.axisDependency = .right
set2.mode = .stepped
set2.colors = [.red]
set2.circleColors = [.white]
set2.lineWidth = 2.0
set2.circleRadius = 3.0
set2.fillAlpha = 65 / 255.0
set2.fillColor = .red
set2.highlightColor = .red
set2.highlightEnabled = true
set2.drawCirclesEnabled = false

set3 = LineChartDataSet(values: yVals3, label: "DataSet 3")
set3.axisDependency = .right
set3.mode = .stepped
set3.colors = [.red]
set3.circleColors = [.white]
set3.lineWidth = 2.0
set3.circleRadius = 3.0
set3.fillAlpha = 65 / 255.0
set3.fillColor = NSUIColor.yellow.withAlphaComponent(200 / 255.0)
set3.highlightColor = .green
set3.highlightEnabled = true
set3.drawCirclesEnabled = false

var dataSets = [LineChartDataSet]()
dataSets.append(set1)
//dataSets.append(set2)
//dataSets.append(set3)
/*:---*/
//: ### LineChartData
let data = LineChartData(dataSets: dataSets)
data.setDrawValues(false)
data.setValueTextColor(#colorLiteral(red: 1, green: 1, blue: 1, alpha: 1))
data.setValueFont(NSUIFont(name: "HelveticaNeue-Light", size: CGFloat(9.0)))
chartView.data = data
/*:---*/
//: ### Setup for the live view
PlaygroundPage.current.liveView = chartView


/*:
 ****
 [Previous](@previous) | [Next](@next)
 */
